pub enum ResponseExpectation {
None,
Message(MessageId),
OptionalMessage(MessageId),
VersionSelected {
before: MessageId,
from: MessageId,
minimum_protocol: u8,
},
SessionSelected {
before: MessageId,
from: MessageId,
selector: SessionResponseSelector,
},
OneOf(&'static [MessageId]),
}Expand description
SCCP-level response expected for a request or media transaction.
Variants
None
Message(MessageId)
OptionalMessage(MessageId)
VersionSelected
The negotiated protocol selects the response identifier.
Fields
SessionSelected
Negotiated session inputs select the response identifier.
Fields

selector: SessionResponseSelectorSession rule that chooses between the response identifiers.
OneOf(&'static [MessageId])
The response may be any member of this family.