pub enum SessionResponseSelector {
DynamicMessagesOrProtocol {
minimum_protocol: u8,
},
DynamicMessages,
}Expand description
Session rule used to select a dynamic response identifier.
Variants
DynamicMessagesOrProtocol
Select the dynamic form when the feature is present or the negotiated protocol meets the stated minimum.
DynamicMessages
Select the dynamic form only when the feature is present.