pub struct ParticipantChangeRouting {
pub application_id: ApplicationId,
pub line_instance: u32,
pub transaction_id: TransactionId,
pub sequence_flag: u32,
pub display_priority: u32,
pub application_instance_id: ApplicationId,
pub routing: u32,
}Expand description
Routing metadata for a participant change carried by the V1 application envelope rather than a standalone station message identifier.
Fields
application_id: ApplicationIdline_instance: u32transaction_id: TransactionIdsequence_flag: u32display_priority: u32application_instance_id: ApplicationIdrouting: u32Trait Implementations
Sourceimpl Clone for ParticipantChangeRouting
impl Clone for ParticipantChangeRouting
Sourcefn clone(&self) -> ParticipantChangeRouting
fn clone(&self) -> ParticipantChangeRouting
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ParticipantChangeRouting
Sourceimpl Debug for ParticipantChangeRouting
impl Debug for ParticipantChangeRouting
impl Eq for ParticipantChangeRouting
Sourceimpl PartialEq for ParticipantChangeRouting
impl PartialEq for ParticipantChangeRouting
impl StructuralPartialEq for ParticipantChangeRouting