StartMultimediaTransmission

Struct StartMultimediaTransmission 

pub struct StartMultimediaTransmission {
    pub conference_id: ConferenceId,
    pub passthrough_party_id: PassthroughPartyId,
    pub endpoint: MediaEndpointAddress,
    pub call_reference: CallReference,
    pub payload: MultimediaPayload,
    pub traffic_class: MediaTrafficClass,
    pub encryption: Option<MediaEncryption>,
    pub stream_passthrough_id: u32,
    pub associated_stream_id: u32,
}
Request to transmit a multimedia stream to a remote endpoint.

Fields

conference_id: ConferenceIdpassthrough_party_id: PassthroughPartyIdendpoint: MediaEndpointAddresscall_reference: CallReferencepayload: MultimediaPayloadtraffic_class: MediaTrafficClassencryption: Option<MediaEncryption>

Optional SRTP parameters carried by extended layouts.

stream_passthrough_id: u32

Identity for this media stream within the conference.

associated_stream_id: u32

Related stream identity, or zero when the stream is independent.