pub struct PhoneAuthenticationUserId(/* private fields */);Expand description
User identifier forwarded by the phone to its authentication service.
Implementations
Sourceimpl PhoneAuthenticationUserId
impl PhoneAuthenticationUserId
Sourcepub fn new(value: impl Into<String>) -> Result<Self, PhoneAuthenticationError>
pub fn new(value: impl Into<String>) -> Result<Self, PhoneAuthenticationError>
Validates and wraps a credential without exposing it through diagnostics.
Sourcepub fn expose_secret(&self) -> &str
pub fn expose_secret(&self) -> &str
Exposes the credential only to an authentication policy implementation.