pub enum PhoneServiceError {
Xml(PhoneXmlError),
InvalidUtf8,
InvalidPercentEncoding,
ControlCharacter,
TooManyRouteSegments {
actual: usize,
maximum: usize,
},
TooManyValues {
actual: usize,
maximum: usize,
},
EmptyParameterName,
EmptyRouteComponent,
ComponentTooLong {
kind: &'static str,
actual: usize,
maximum: usize,
},
}Expand description
Failures while validating or decoding an application payload.
Variants
Xml(PhoneXmlError)
A structured XML payload was malformed or violated its schema bounds.
InvalidUtf8
InvalidPercentEncoding
ControlCharacter
TooManyRouteSegments
The route exceeded MAX_PHONE_SERVICE_ROUTE_SEGMENTS.
TooManyValues
The query exceeded MAX_PHONE_SERVICE_SUBMITTED_VALUES.
EmptyParameterName
EmptyRouteComponent
ComponentTooLong
A decoded route, name, or value exceeded its corresponding byte limit.