pub enum PhoneImageDocument {
Image(CiscoIpPhoneImage),
ImageFile(CiscoIpPhoneImageFile),
GraphicMenu(CiscoIpPhoneGraphicMenu),
GraphicFileMenu(CiscoIpPhoneGraphicFileMenu),
}Expand description
Any accepted image-service document family.
Variants
Image(CiscoIpPhoneImage)
ImageFile(CiscoIpPhoneImageFile)
GraphicMenu(CiscoIpPhoneGraphicMenu)
GraphicFileMenu(CiscoIpPhoneGraphicFileMenu)
Implementations
Sourceimpl PhoneImageDocument
impl PhoneImageDocument
Sourcepub fn validate(&self) -> Result<(), PhoneXmlError>
pub fn validate(&self) -> Result<(), PhoneXmlError>
Applies the invariants for the selected image family.
Sourcepub fn from_xml(document: &[u8]) -> Result<Self, PhoneXmlError>
pub fn from_xml(document: &[u8]) -> Result<Self, PhoneXmlError>
Detects the root and parses any supported image family.
Sourcepub fn to_xml(&self) -> Result<String, PhoneXmlError>
pub fn to_xml(&self) -> Result<String, PhoneXmlError>
Validates and serializes the selected family using PHONE_IMAGE_MAX_BYTES.
Sourcepub fn to_xml_with_limit(
&self,
maximum_bytes: usize,
) -> Result<String, PhoneXmlError>
pub fn to_xml_with_limit( &self, maximum_bytes: usize, ) -> Result<String, PhoneXmlError>
Validates and serializes the selected family within a caller-selected limit.