pub enum PhoneStatusDocument {
Bitmap(CiscoIpPhoneStatus),
File(CiscoIpPhoneStatusFile),
}Expand description
Either accepted status-service document family.
Variants
Bitmap(CiscoIpPhoneStatus)
File(CiscoIpPhoneStatusFile)
Implementations
Sourceimpl PhoneStatusDocument
impl PhoneStatusDocument
Sourcepub fn validate(&self) -> Result<(), PhoneXmlError>
pub fn validate(&self) -> Result<(), PhoneXmlError>
Applies the invariants for the selected status family.
Sourcepub fn from_xml(document: &[u8]) -> Result<Self, PhoneXmlError>
pub fn from_xml(document: &[u8]) -> Result<Self, PhoneXmlError>
Detects the root and parses either supported status family.
Sourcepub fn to_xml(&self) -> Result<String, PhoneXmlError>
pub fn to_xml(&self) -> Result<String, PhoneXmlError>
Validates and serializes the selected family using PHONE_STATUS_MAX_BYTES.
Sourcepub fn to_xml_with_limit(
&self,
maximum_bytes: usize,
) -> Result<String, PhoneXmlError>
pub fn to_xml_with_limit( &self, maximum_bytes: usize, ) -> Result<String, PhoneXmlError>
Validates and serializes the selected family within a caller-selected limit.