pub struct CiscoIpPhoneExecute {
pub items: Vec<CiscoIpPhoneExecuteItem>,
}Expand description
A complete, schema-ordered execute document.
Fields
items: Vec<CiscoIpPhoneExecuteItem>Implementations
Sourceimpl CiscoIpPhoneExecute
impl CiscoIpPhoneExecute
Sourcepub fn new(items: Vec<CiscoIpPhoneExecuteItem>) -> Result<Self, PhoneXmlError>
pub fn new(items: Vec<CiscoIpPhoneExecuteItem>) -> Result<Self, PhoneXmlError>
Builds a document containing one to PHONE_EXECUTE_MAX_ITEMS actions.
Sourcepub fn validate(&self) -> Result<(), PhoneXmlError>
pub fn validate(&self) -> Result<(), PhoneXmlError>
Checks action count and the single-HTTP-action invariant.
Sourceimpl CiscoIpPhoneExecute
impl CiscoIpPhoneExecute
Sourcepub fn from_xml(document: &[u8]) -> Result<Self, PhoneXmlError>
pub fn from_xml(document: &[u8]) -> Result<Self, PhoneXmlError>
Parses and validates this document using its schema byte limit.
Sourcepub fn from_xml_with_limit(
document: &[u8],
maximum_bytes: usize,
) -> Result<Self, PhoneXmlError>
pub fn from_xml_with_limit( document: &[u8], maximum_bytes: usize, ) -> Result<Self, PhoneXmlError>
Parses and validates this document with a stricter byte limit.
Sourcepub fn to_xml(&self) -> Result<String, PhoneXmlError>
pub fn to_xml(&self) -> Result<String, PhoneXmlError>
Validates and serializes this document using its schema byte limit.
Sourcepub fn to_xml_with_limit(
&self,
maximum_bytes: usize,
) -> Result<String, PhoneXmlError>
pub fn to_xml_with_limit( &self, maximum_bytes: usize, ) -> Result<String, PhoneXmlError>
Validates and serializes this document with a stricter byte limit.