CiscoIpPhoneIconFileMenu

Struct CiscoIpPhoneIconFileMenu 

pub struct CiscoIpPhoneIconFileMenu {
Show 13 fields pub keypad_target: Option<PhoneKeypadTarget>, pub application_id: Option<String>, pub on_focus_lost: Option<String>, pub on_focus_gained: Option<String>, pub on_minimized: Option<String>, pub on_closed: Option<String>, pub icon_index: Option<u16>, pub title: Option<CiscoIpPhoneIconTitle>, pub prompt: Option<String>, pub soft_keys: Vec<CiscoIpPhoneSoftKeyItem>, pub key_items: Vec<CiscoIpPhoneKeyItem>, pub items: Vec<CiscoIpPhoneIconMenuItem>, pub icons: Vec<CiscoIpPhoneIconFileItem>,
}
A complete menu whose icons are loaded from resource URLs.

Fields

keypad_target: Option<PhoneKeypadTarget>application_id: Option<String>on_focus_lost: Option<String>on_focus_gained: Option<String>on_minimized: Option<String>on_closed: Option<String>icon_index: Option<u16>

Optional icon index in 0..=9 displayed beside the title.

title: Option<CiscoIpPhoneIconTitle>prompt: Option<String>soft_keys: Vec<CiscoIpPhoneSoftKeyItem>key_items: Vec<CiscoIpPhoneKeyItem>items: Vec<CiscoIpPhoneIconMenuItem>icons: Vec<CiscoIpPhoneIconFileItem>

Implementations

Source

impl CiscoIpPhoneIconFileMenu

pub fn from_xml(document: &[u8]) -> Result<Self, PhoneXmlError>

Parses and validates this document using its schema byte limit.

pub fn from_xml_with_limit( document: &[u8], maximum_bytes: usize, ) -> Result<Self, PhoneXmlError>

Parses and validates this document with a stricter byte limit.

pub fn to_xml(&self) -> Result<String, PhoneXmlError>

Validates and serializes this document using its schema byte limit.

pub fn to_xml_with_limit( &self, maximum_bytes: usize, ) -> Result<String, PhoneXmlError>

Validates and serializes this document with a stricter byte limit.

Source

impl CiscoIpPhoneIconFileMenu

pub fn validate(&self) -> Result<(), PhoneXmlError>

Validates display metadata, choice bounds, and referenced icons.