pub struct CiscoIpPhoneImageList {
pub items: Vec<CiscoIpPhoneImageListItem>,
}Expand description
The ordered background choices pulled from a desktop List.xml resource.
Fields
items: Vec<CiscoIpPhoneImageListItem>Implementations
Sourceimpl CiscoIpPhoneImageList
impl CiscoIpPhoneImageList
Sourcepub fn from_xml(document: &[u8]) -> Result<Self, PhoneXmlError>
pub fn from_xml(document: &[u8]) -> Result<Self, PhoneXmlError>
Parses and validates this document using its schema byte limit.
Sourcepub fn from_xml_with_limit(
document: &[u8],
maximum_bytes: usize,
) -> Result<Self, PhoneXmlError>
pub fn from_xml_with_limit( document: &[u8], maximum_bytes: usize, ) -> Result<Self, PhoneXmlError>
Parses and validates this document with a stricter byte limit.
Sourcepub fn to_xml(&self) -> Result<String, PhoneXmlError>
pub fn to_xml(&self) -> Result<String, PhoneXmlError>
Validates and serializes this document using its schema byte limit.
Sourcepub fn to_xml_with_limit(
&self,
maximum_bytes: usize,
) -> Result<String, PhoneXmlError>
pub fn to_xml_with_limit( &self, maximum_bytes: usize, ) -> Result<String, PhoneXmlError>
Validates and serializes this document with a stricter byte limit.
Sourceimpl CiscoIpPhoneImageList
impl CiscoIpPhoneImageList
Sourcepub fn new(items: Vec<CiscoIpPhoneImageListItem>) -> Result<Self, PhoneXmlError>
pub fn new(items: Vec<CiscoIpPhoneImageListItem>) -> Result<Self, PhoneXmlError>
Builds and validates an ordered list of background choices.
Sourcepub fn validate(&self) -> Result<(), PhoneXmlError>
pub fn validate(&self) -> Result<(), PhoneXmlError>
Enforces PHONE_BACKGROUND_LIST_MAX_ITEMS.