pub struct CiscoIpPhoneMenu {
pub keypad_target: Option<PhoneKeypadTarget>,
pub application_id: Option<String>,
pub on_focus_lost: Option<String>,
pub on_focus_gained: Option<String>,
pub on_minimized: Option<String>,
pub on_closed: Option<String>,
pub title: Option<String>,
pub prompt: Option<String>,
pub soft_keys: Vec<CiscoIpPhoneSoftKeyItem>,
pub key_items: Vec<CiscoIpPhoneKeyItem>,
pub items: Vec<CiscoIpPhoneMenuItem>,
}Expand description
A complete plain menu with optional lifecycle and physical-key actions.
Fields
keypad_target: Option<PhoneKeypadTarget>application_id: Option<String>on_focus_lost: Option<String>on_focus_gained: Option<String>on_minimized: Option<String>on_closed: Option<String>title: Option<String>prompt: Option<String>soft_keys: Vec<CiscoIpPhoneSoftKeyItem>key_items: Vec<CiscoIpPhoneKeyItem>items: Vec<CiscoIpPhoneMenuItem>Implementations
Sourceimpl CiscoIpPhoneMenu
impl CiscoIpPhoneMenu
Sourcepub fn from_xml(document: &[u8]) -> Result<Self, PhoneXmlError>
pub fn from_xml(document: &[u8]) -> Result<Self, PhoneXmlError>
Parses and validates this document using its schema byte limit.
Sourcepub fn from_xml_with_limit(
document: &[u8],
maximum_bytes: usize,
) -> Result<Self, PhoneXmlError>
pub fn from_xml_with_limit( document: &[u8], maximum_bytes: usize, ) -> Result<Self, PhoneXmlError>
Parses and validates this document with a stricter byte limit.
Sourcepub fn to_xml(&self) -> Result<String, PhoneXmlError>
pub fn to_xml(&self) -> Result<String, PhoneXmlError>
Validates and serializes this document using its schema byte limit.
Sourcepub fn to_xml_with_limit(
&self,
maximum_bytes: usize,
) -> Result<String, PhoneXmlError>
pub fn to_xml_with_limit( &self, maximum_bytes: usize, ) -> Result<String, PhoneXmlError>
Validates and serializes this document with a stricter byte limit.
Sourceimpl CiscoIpPhoneMenu
impl CiscoIpPhoneMenu
Sourcepub fn new(
title: impl Into<String>,
prompt: impl Into<String>,
items: Vec<CiscoIpPhoneMenuItem>,
) -> Result<Self, PhoneXmlError>
pub fn new( title: impl Into<String>, prompt: impl Into<String>, items: Vec<CiscoIpPhoneMenuItem>, ) -> Result<Self, PhoneXmlError>
Builds and validates a menu with no optional lifecycle actions.
Sourcepub fn validate(&self) -> Result<(), PhoneXmlError>
pub fn validate(&self) -> Result<(), PhoneXmlError>
Validates display metadata and the bounded list of menu choices.