pub struct CiscoIpPhoneText {
pub keypad_target: Option<PhoneKeypadTarget>,
pub application_id: Option<String>,
pub on_focus_lost: Option<String>,
pub on_focus_gained: Option<String>,
pub on_minimized: Option<String>,
pub on_closed: Option<String>,
pub title: Option<String>,
pub prompt: Option<String>,
pub soft_keys: Vec<CiscoIpPhoneSoftKeyItem>,
pub key_items: Vec<CiscoIpPhoneKeyItem>,
pub text: Option<String>,
}Expand description
A complete, schema-ordered text display document.
Fields
keypad_target: Option<PhoneKeypadTarget>application_id: Option<String>on_focus_lost: Option<String>on_focus_gained: Option<String>on_minimized: Option<String>on_closed: Option<String>title: Option<String>prompt: Option<String>soft_keys: Vec<CiscoIpPhoneSoftKeyItem>key_items: Vec<CiscoIpPhoneKeyItem>text: Option<String>Implementations
Sourceimpl CiscoIpPhoneText
impl CiscoIpPhoneText
Sourcepub fn new(
title: impl Into<String>,
prompt: impl Into<String>,
text: impl Into<String>,
) -> Result<Self, PhoneXmlError>
pub fn new( title: impl Into<String>, prompt: impl Into<String>, text: impl Into<String>, ) -> Result<Self, PhoneXmlError>
Builds and validates a text page with no optional lifecycle actions.
Sourcepub fn validate(&self) -> Result<(), PhoneXmlError>
pub fn validate(&self) -> Result<(), PhoneXmlError>
Validates display metadata and the text-body character bound.
Sourceimpl CiscoIpPhoneText
impl CiscoIpPhoneText
Sourcepub fn from_xml(document: &[u8]) -> Result<Self, PhoneXmlError>
pub fn from_xml(document: &[u8]) -> Result<Self, PhoneXmlError>
Parses and validates this document using its schema byte limit.
Sourcepub fn from_xml_with_limit(
document: &[u8],
maximum_bytes: usize,
) -> Result<Self, PhoneXmlError>
pub fn from_xml_with_limit( document: &[u8], maximum_bytes: usize, ) -> Result<Self, PhoneXmlError>
Parses and validates this document with a stricter byte limit.
Sourcepub fn to_xml(&self) -> Result<String, PhoneXmlError>
pub fn to_xml(&self) -> Result<String, PhoneXmlError>
Validates and serializes this document using its schema byte limit.
Sourcepub fn to_xml_with_limit(
&self,
maximum_bytes: usize,
) -> Result<String, PhoneXmlError>
pub fn to_xml_with_limit( &self, maximum_bytes: usize, ) -> Result<String, PhoneXmlError>
Validates and serializes this document with a stricter byte limit.