pub struct QosTransition { /* private fields */ }Expand description
Ordered service-node writes and state events produced by one transition.
Implementations
Sourceimpl QosTransition
impl QosTransition
Sourcepub fn messages(&self) -> &[ControlMessage]
pub fn messages(&self) -> &[ControlMessage]
Borrows service-node writes in their required emission order.
Sourcepub fn events(&self) -> &[QosReservationEvent]
pub fn events(&self) -> &[QosReservationEvent]
Borrows events in the order produced by the corresponding state change.
Sourcepub fn into_parts(self) -> (Vec<ControlMessage>, Vec<QosReservationEvent>)
pub fn into_parts(self) -> (Vec<ControlMessage>, Vec<QosReservationEvent>)
Transfers both ordered output queues to a transport/event owner.