AddonModuleDefinition

Struct AddonModuleDefinition 

pub struct AddonModuleDefinition {
    pub slot: u32,
    pub device_type: DeviceType,
}
An expansion module and the station slot where it is attached.

Fields

slot: u32

One-based expansion-module slot.

device_type: DeviceType

Implementations

Source

impl AddonModuleDefinition

pub const fn button_capacity(&self) -> Option<usize>

Number of physical programmable keys supplied by this sidecar model.