pub struct LineDefinition {
pub number: String,
pub display_name: String,
}Expand description
A logical directory number and its default station label.
A logical line may be presented on more than one station through distinct
LineAppearance values.
Fields
number: StringNonempty directory number; DeviceDefinition::validate limits it to
24 bytes when used by a station.
display_name: StringTrait Implementations
Sourceimpl Clone for LineDefinition
impl Clone for LineDefinition
Sourcefn clone(&self) -> LineDefinition
fn clone(&self) -> LineDefinition
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LineDefinition
impl Debug for LineDefinition
impl Eq for LineDefinition
Sourceimpl PartialEq for LineDefinition
impl PartialEq for LineDefinition
impl StructuralPartialEq for LineDefinition