pub struct StationSessionContext {
pub protocol: ProtocolVersion,
pub features: PhoneFeatures,
}Expand description
Negotiated inputs that select station-facing message layouts.
Fields
protocol: ProtocolVersionNegotiated frame and payload version.
features: PhoneFeaturesStation feature bits that can select layouts independently of version.
Implementations
Sourceimpl StationSessionContext
impl StationSessionContext
Sourcepub const fn new(protocol: ProtocolVersion, features: PhoneFeatures) -> Self
pub const fn new(protocol: ProtocolVersion, features: PhoneFeatures) -> Self
Creates the layout-selection context for a registered station session.
Sourcepub const fn uses_dynamic_general_ui(self) -> bool
pub const fn uses_dynamic_general_ui(self) -> bool
Reports whether general UI responses use their dynamic string layouts.
Sourcepub const fn uses_dynamic_feature_status(self) -> bool
pub const fn uses_dynamic_feature_status(self) -> bool
Reports whether feature status uses its dynamic response identifier.
Sourcepub const fn uses_dynamic_speed_dial_status(self) -> bool
pub const fn uses_dynamic_speed_dial_status(self) -> bool
Reports whether speed-dial status uses the dynamic identifier and variable-string payload selected by the registered station session.
Sourcepub const fn dynamic_call_info_layout(self) -> DynamicCallInfoLayout
pub const fn dynamic_call_info_layout(self) -> DynamicCallInfoLayout
Returns the call-info string layout selected by the negotiated version.
Sourcepub const fn dynamic_service_url_string_count(self) -> usize
pub const fn dynamic_service_url_string_count(self) -> usize
Returns the dynamic service-URL string count selected by the session.